package main

import (
	"runtime/debug"
	"strings"

	"gopkg.in/yaml.v3"
)

var (
	version string
	commit  string

	imagesVersion string
)

func init() {
	if version == "" {
		version = "unknown"
	}

	if bi, ok := debug.ReadBuildInfo(); ok {
		for _, bs := range bi.Settings {
			switch bs.Key {
			case "vcs.revision":
				commit = bs.Value
			}
		}

		for _, dep := range bi.Deps {
			if dep.Path == "github.com/osbuild/images" {
				imagesVersion = dep.Version
			}
		}
	}

	// If we didnt find any commit info, we set it to unknown
	if commit == "" {
		commit = "unknown"
	}

	// If we didn't find any dependency info, we set it to unknown
	if imagesVersion == "" {
		imagesVersion = "unknown"
	}
}

type versionDescription struct {
	ImageBuilder struct {
		Version      string `yaml:"version"`
		Commit       string `yaml:"commit"`
		Dependencies struct {
			Images string `yaml:"images"`
		} `yaml:"dependencies"`
	} `yaml:"image-builder"`
}

func PrettyVersion() string {
	var b strings.Builder

	vd := versionDescription{}

	vd.ImageBuilder.Version = version
	vd.ImageBuilder.Commit = commit

	vd.ImageBuilder.Dependencies.Images = imagesVersion

	enc := yaml.NewEncoder(&b)
	enc.SetIndent(2)

	enc.Encode(&vd)

	return b.String()
}
